/*******************************************************************************
 Project:
 	TW-RMSDC
 Descriptions:
 	These functions are for scanning the swich and controlling Relay & LED
 	IDE: MPLAB IDE v8.92
 	Compiler: PIC C18
 	Copyright(C) 2016 Akihiro Kawata, Triple W Japan Inc.
 	Last Update by A.KAWATA, 12/12/2016
********************************************************************************/
#include <p18f24j10.h>
#include "CTRLio.h"
#include "WAITfunc.h"

/*******************************************************************************
 Scanning Switch condition including De-chattering process
 Return value: Command# (0 to 4)
 0: idleSW function
 1: set 50uV  FS function
 2: set 500uV FS function
 3: set 50mV  FS function
 4: set 5V    FS function
********************************************************************************/
unsigned char getSW(void)
{
	if(!SW50UV) {
		// Judge to turn off (Push) the SW50UV
		// De-chattering process
		while(1) {
			// OFF??
			if(!SW50UV) { continue; } wait_2ms(3);
			// OFF?
			if(!SW50UV) { continue; } wait_2ms(3);
			// Check to turn ON state
			if(SW50UV) { break; }
		}
		return (1);
	}
	else if(!SW500UV) {
		// Judge to turn off (Push) the SW500UV
		// De-chattering process
		while(1) {
			// OFF??
			if(!SW500UV) { continue; } wait_2ms(3);
			// OFF?
			if(!SW500UV) { continue; } wait_2ms(3);
			// Check to turn ON state
			if(SW500UV) { break; }
		}
		return (2);
	}
	else if(!SW50MV) {
		// Judge to turn off (Push) the SW50MV
		// De-chattering process
		while(1) {
			// OFF??
			if(!SW50MV) { continue; } wait_2ms(3);
			// OFF?
			if(!SW50MV) { continue; } wait_2ms(3);
			// Check to turn ON state
			if(SW50MV) { break; }
		}
		return (3);
	}
	else if(!SW5V) {
		// Judge to turn off (Push) the SW5V
		// De-chattering process
		while(1) {
			// OFF??
			if(!SW5V) { continue; } wait_2ms(3);
			// OFF?
			if(!SW5V) { continue; } wait_2ms(3);
			// Check to turn ON state
			if(SW5V) { break; }
		}
		return (4);
	}
	else return (0);
}

/*******************************************************************************
 Set Relay to 50uV FS range
********************************************************************************/
void set50UV(void)
{
	setRL1();
	setRL2();
	LNAEN = 1;
	LED50UV = 0; LED500UV = 1; LED50MV = 1; LED5V = 1;
}

/*******************************************************************************
 Set Relay to 500uV FS range
********************************************************************************/
void set500UV(void)
{
	setRL1();
	resetRL2();
	LNAEN = 1;
	LED50UV = 1; LED500UV = 0; LED50MV = 1; LED5V = 1;
}

/*******************************************************************************
 Set Relay to 50mV FS range
********************************************************************************/
void set50MV(void)
{
	resetRL1();
	setRL2();
	LNAEN = 0;
	LED50UV = 1; LED500UV = 1; LED50MV = 0; LED5V = 1;
}

/*******************************************************************************
 Set Relay to 5V FS range
********************************************************************************/
void set5V(void)
{
	resetRL1();
	resetRL2();
	LNAEN = 0;
	LED50UV = 1; LED500UV = 1; LED50MV = 1; LED5V = 0;
}

/*******************************************************************************
 Generate latching Pulse for SET of RL1
********************************************************************************/
void setRL1(void)
{
	SET1 = 1;
	// Setup time of the Relay is 5ms.
	// Thus the wait time needs more than 5 times.
	wait_2ms(15);
	SET1 = 0;
}

/*******************************************************************************
 Generate latching Pulse for RESET of RL1
********************************************************************************/
void resetRL1(void)
{
	RST1 = 1;
	// Setup time of the Relay is 5ms.
	// Thus the wait time needs more than 5 times.
	wait_2ms(15);
	RST1 = 0;
}

/*******************************************************************************
 Generate latching Pulse for SET of RL2
********************************************************************************/
void setRL2(void)
{
	SET2 = 1;
	// Setup time of the Relay is 5ms.
	// Thus the wait time needs more than 5 times.
	wait_2ms(15);
	SET2 = 0;
}

/*******************************************************************************
 Generate latching Pulse for RESET of RL2
********************************************************************************/
void resetRL2(void)
{
	RST2 = 1;
	// Setup time of the Relay is 5ms.
	// Thus the wait time needs more than 5 times.
	wait_2ms(15);
	RST2 = 0;
}

/*******************************************************************************
 Dummy function for idle
********************************************************************************/
void idleSW(void) {}

/*******************************************************************************
 List of Function's Pointer
********************************************************************************/
RANGE func_sw[5] = { idleSW, set50UV, set500UV, set50MV, set5V };
